@@ -2,7 +2,7 @@
 
 __author__ = """PragmaLingu"""
 __email__ = 'info@pragmalingu.de'
-__version__ = '0.1.6'
+__version__ = '0.1.9'
 
 import csv
 from collections import OrderedDict, defaultdict
@@ -443,7 +443,11 @@ class EvaluationObject:
         explain = defaultdict(lambda: defaultdict(lambda: []))
         explanation = self.elasticsearch.explain(self.index, doc_id, query_body)['explanation']
         explain["score"] = explanation['value']
-        if len(fields) < 2:
+        if explain["score"] == 0.0:
+            print('No hits with that request, please check all the parameters like index, fields, query dictionary, '
+                  'etc.')
+            return explanation
+        if explanation['description'] != "max of:":
             explanation = {'details': [explanation]}
 
         for el in explanation['details']:
@@ -675,8 +679,7 @@ class ComparisonTool:
         """
         if not eval_objs:
             eval_objs = [self.eval_obj_1, self.eval_obj_2]
-        if not queries:
-            queries = eval_objs[0]._check_searched_queries(queries)
+        queries = eval_objs[0]._check_searched_queries(queries)
         panda_dist = self._get_distributions(queries, eval_objs, distributions)
         dist_colors = [self.pragma_colors[1], self.pragma_colors[4], self.pragma_colors[5]]
         custom_palette = sns.set_palette(sns.color_palette(dist_colors))
@@ -701,8 +704,7 @@ class ComparisonTool:
             conditions = ['precision', 'recall', 'fscore']
         if not eval_objs:
             eval_objs = [self.eval_obj_1, self.eval_obj_2]
-        if not queries:
-            queries = eval_objs[0]._check_searched_queries(queries)
+        queries = eval_objs[0]._check_searched_queries(queries)
         panda_cond = self._get_conditions(queries, eval_objs, conditions)
         custom_palette = sns.set_palette(sns.color_palette(self.pragma_colors))
         sns.set_theme(context='paper', style='whitegrid', palette=custom_palette)
